<?php
/**
 * CDataFilterWidget class file.
 *
 * @author Seb <serebrov@algo-rithm.com>, Algo-rithm
 *
 * @version 0.1
 *
 * @desc CDataFilterWidget renders filter and search controls represented by
 * CDataFilter class.
 *
 */
class CDataFilterWidget extends CWidget
{
    /**
     * @var CDataFilter filters data
     */
    private $_filters;

    /**
     * @var boolean if set to true - ajax filtration / search will be enabled
     */
    private $_ajaxMode = false;
    /**
     *
     * @var string selector name of html element to update by ajax request
     */
    private $_updateSelector = "#updateData";

    /**
     * @var mixed the CSS file used for the widget. Defaults to null, meaning
     * using the default CSS file included together with the widget.
     * If false, no CSS file will be used. Otherwise, the specified CSS file
     * will be included when using this widget.
     */
    public $cssFile;

    public $groupDefaultStyle = 'dataFilterInline';
    public $groupStyles = array();

    public $groupView = 'dataFilterGroup';
    public $groupFieldsSeparator = '';


    public function init()
    {
        if($this->cssFile===null)
        {
            $file=dirname(__FILE__).DIRECTORY_SEPARATOR.'datafilter.css';
            $this->cssFile=Yii::app()->getAssetManager()->publish($file);
        }
        parent::init();
    }

    /**
     * Returns the filters information used by this widget.
     * @return CDataFilter
     */
    public function getFilters()
    {
        return $this->_filters;
    }

    /**
     * Sets the filters information used by this widget.
     * @param CDataFilter
     */
    public function setFilters($filters)
    {
        $this->_filters = $filters;
    }

    /**
     *
     * @return <boolean> is ajax mode enabled
     */
    public function getAjaxMode()
    {
        return $this->_ajaxMode;
    }

    /**
     *
     * @param <boolean> $mode - set to true to enable ajax filtration
     */
    public function setAjaxMode($mode)
    {
        $this->_ajaxMode = $mode;
    }

    public function getGroupStyles()
    {
        return $this->groupStyles;
    }

    public function setGroupStyles($styles)
    {
        $this->groupStyles = $styles;
    }


    /**
     *
     * @return <string> selector name - jQuery will update element(s)
     *                  found using this selector after request finished
     */
    public function getUpdateSelector()
    {
        return $this->_updateSelector;
    }

    /**
     *
     * @param <string> $selector - set selector name
     */
    public function setUpdateSelector($selector)
    {
        $this->_updateSelector = $selector;
    }


    /**
     * Executes the widget.
     * This overrides the parent implementation by displaying the generated page buttons.
     */
    public function run()
    {
        //no filters - no widget!
        if ($this->getFilters() != null) {
            $this->buildWidget();
        }
    }

    /**
     * Builds widget
     */
    private function buildWidget()
    {
        $groupsData = array();

        $searchFilters = '';
        $dropDownFilters = '';
        $linkFilters = '';

        foreach ($this->getFilters()->filters as $filter) {            
            if (!isset($groupsData[$filter->group])) {    
                $groupsData[$filter->group] = $filter->buildFilterCode($this);
            } else {
                $groupsData[$filter->group] .= $this->groupFieldsSeparator . $filter->buildFilterCode($this);
            }
        }

        echo CHtml::form('','get');

        foreach ($groupsData as $group=>$data) {
            $style = isset($this->groupStyles[$group]) ? $this->groupStyles[$group] : $this->groupDefaultStyle;
            echo $this->render($this->groupView, array('group'=>$group, 'data'=>$data, 'groupClass'=>$style), true);
        }
        echo CHtml::endForm();

        $this->registerClientScript();
    }    

    public function getModel()
    {
        return $this->getFilters()->model;
    }


    /**
     * Registers the needed client scripts (mainly CSS file).
     */
    public function registerClientScript()
    {
        if($this->cssFile!==false)
            self::registerCssFile($this->cssFile);
    }

    /**
     * Registers the needed CSS file.
     * @param string the CSS URL. If null, a default CSS URL will be used.
     * @since 1.0.2
     */
    public static function registerCssFile($url=null)
    {
        Yii::app()->getClientScript()->registerCssFile($url);
    }


}