<?php
class CFilterDropdown extends CFilterBase
{
    public $displayName;
    public $emptyValue;
    public $specialOptions;


    public function __construct($filterName, $filterGroup, $filterDisplayName,
        $emptyValue = "All", $specialOptions = array())
    {
        parent::__construct($filterName, $filterGroup);

        $this->displayName = $filterDisplayName;
        $this->emptyValue = $emptyValue;
        $this->specialOptions = $specialOptions;

        if (empty($emptyValue)) {
            $options = $this->model->getDataFilterOptions($filterName);            
            $values = array_keys($options);
            list ($value, $name) = each($options);
            // If there is no empty filter value and web page is shown first time
            // (because !isset($_GET[$filterName] = true) - we should change $_GET[$filterName] to first
            // filter value and data will be filtered
            // The second check - !in_array($_GET[$filterName], $values)
            // is for case, when filter's options was changed (because of dependency on another filter)
            // then we need to rewrite $_GET[$filterName] to show correct data
            if (!isset($_GET[$filterName]) || !in_array($_GET[$filterName], $values)) {
                $_GET[$filterName] = $value;
            }
        }

    }    

    public function applyCriteria($model, &$criteria)
    {           
        $model->applyDataFilterCriteria($criteria,
            $this->name, $this->getValue()
        );
    }

    public function buildFilterCode($widget)
    {
        // 'submit' parameter handeled internally by javaScript causing problems
        // with ajax-enabled pages (for example page wich renders partial data grig
        // using ajax pagination - in such case yii's submit handler becomes broken)
        //$params = $this->_ajaxMode ? array() : array('submit'=>'');
        $params = $widget->getAjaxMode() ? array() : array('onchange'=>'this.form.submit();');
        if (!empty($this->emptyValue)) {
            $params['empty'] = $this->emptyValue;
        }
        $data = $this->getDataFilterOptions($widget->model);

        $data = $this->specialOptions + $data;
        return $widget->render('dropdown', array('filter'=>$this, 
            'data'=>$data, 'params'=>$params), true);
    }

    /**
     * Returns options for dropdown filter, throws an exception if model returns an empty set
     * @param <string> $filterName
     * @return <string> options for dropdown
     */
    private function getDataFilterOptions($model)
    {
        $options = $model->getDataFilterOptions($this->name);
        if (!isset($options)) {
            throw new CException('CFilterDropdown: model\'s method '.
                get_class($model) .
                '.getDataFilterOptions() returned empty set.');
        }
        return $options;
    }

    
}
?>