<?php

class User extends CActiveRecord
{
	/**
	 * The followings are the available columns in table 'users':
	 * @var integer $id
	 * @var string $name
	 * @var string $username
	 * @var string $password
	 * @var integer $is_active
     * @var integer $user_groups_id
     * @var integer $cities_id
	 */

	/**
	 * Returns the static model of the specified AR class.
	 * @return CActiveRecord the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}

	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return 'df_users';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		return array(
			array('name','length','max'=>45),
			array('username','length','max'=>45),
			array('password','length','max'=>45)
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
			'group' => array(self::BELONGS_TO, 'Group', 'user_groups_id'),
    		'city' => array(self::BELONGS_TO, 'City', 'cities_id')
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'id' => 'Id',
			'name' => 'Name',
			'user_groups_id' => 'Group',
			'username' => 'Username',
			'password' => 'Password',
			'cities_id' => 'City',
		);
	}


    /*
     * Returns list of searchable fileds for DataFilter widget
     */
    public function getDataFilterSearchFields($filterName)
    {
        switch ($filterName) {
            case 'userFieldsSearch':
                return array(
                    'id'=>'User ID',
                    'name'=>'Name',
                    'username'=>'Username',
                );
        }
    }

   /*
     * Applies search criteria enterd using DataFilter widget
     */
    public function applyDataSearchCriteria(&$criteria, $filterName, $searchField, $searchValue)
    {
        if($filterName == 'userFieldsSearch') {
            $localCriteria = new CDbCriteria;
            $localCriteria->condition = ' '.$searchField.' LIKE "%' .$searchValue.'%" ';
            $criteria->mergeWith($localCriteria);
        }        
    }

    /*
     * Returns options for DataFilter widget
     */
    public function getDataFilterOptions($filterName)
    {
        switch ($filterName) {
            case 'groupFilter':
                $groups = Group::model()->findAll();
                return CHtml::listData($groups, 'id', 'name');
            case 'countryFilter':
                $countries = Country::model()->findAll();
                return CHtml::listData($countries, 'id', 'name');
            case 'cityFilter':
                $criteria = new CDbCriteria;
                if (isset($_GET['countryFilter']) && !empty($_GET['countryFilter'])) {
                    $criteria->condition = ' countries_id = '.$_GET['countryFilter'];
                }
                $cities = City::model()->findAll($criteria);
                return CHtml::listData($cities, 'id', 'name');
        }      
    }

    /*
     * Applies filter criteria enterd using DataFilter widget
     */
    public function applyDataFilterCriteria(&$criteria, $filterName, $filterValue)
    {
        if($filterName == 'groupFilter') {
            $localCriteria = new CDbCriteria;
            $localCriteria->condition = CDataFilter::getCondition('user_groups_id', $filterValue);
            $criteria->mergeWith($localCriteria);
        }

        if($filterName == 'countryFilter') {
            $localCriteria = new CDbCriteria;
            if ($filterValue != 'null') {
                $localCriteria->select = 'df_users.*';
                $localCriteria->join =
                    'INNER JOIN `df_cities` cities
                    ON (`df_users`.`cities_id`=cities.`id`)
                    AND ('.CDataFilter::getCondition('cities.countries_id', $filterValue). ') ';
                //$localCriteria->group = ' df_users.id ';
            } else {
                $localCriteria->condition = ' cities_id is null ';
            }
            $criteria->mergeWith($localCriteria);
        }

        if($filterName == 'cityFilter') {
            $localCriteria = new CDbCriteria;
            $localCriteria->condition = CDataFilter::getCondition('cities_id', $filterValue);
            $criteria->mergeWith($localCriteria);
        }

        if($filterName == 'activeFilter') {
            if ($filterValue !== 'active') return;
            $localCriteria = new CDbCriteria;
            $localCriteria->condition = CDataFilter::getCondition('is_active', 1);
            $criteria->mergeWith($localCriteria);
        }


    }



}